@@ -9,7 +9,8 @@ utils::globalVariables(
     ".", ".SD", "BP", "P", "CHR", "maxBP", "halfBP", "xlabBP", "accum",
     "highlight", "SNP", "xaxis", "P_v2", "y", "a", "x", "upper", "lower",
     "label1", "label2", "MAF", "OR", "Power_at_Alpha_5e-08", "head", "setNames",
-    "ES", "effect_size_value"
+    "ES", "effect_size_value", ".data", "as.formula", "lm", "resid", "cor", "glm",
+    "binomial", "row_num", "sizes", "shape", "start", "end"
   )
 )
 
